summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmslopeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmslopeedit.h')
-rw-r--r--kpovmodeler/pmslopeedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmslopeedit.h b/kpovmodeler/pmslopeedit.h
index a2defaa9..a57816a1 100644
--- a/kpovmodeler/pmslopeedit.h
+++ b/kpovmodeler/pmslopeedit.h
@@ -40,12 +40,13 @@ class TQLabel;
class PMSlopeEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMSlopeEdit with parent and name
*/
- PMSlopeEdit( TQWidget* parent, const char* name = 0 );
+ PMSlopeEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -40,12 +40,13 @@ class TQLabel;
public:
/**
- * Creates a PMSlopeEdit with parent and name
+ * Creates a PMSlopeEdit with tqparent and name
*/